@@ -135,15 +135,15 @@ QPixmap ShareListViewItem::createPropertyPixmap()
 
   int numberOfPix = 4; // the max number of pixmaps to join
 
-  int w = 22; // Standard size of one pixmap
+  int w = 16; // Standard size of one pixmap
   int margin = 4; // Margin between pixmaps
-  int h = 22;
+  int h = 16;
 
   int totalWidth = (w+margin)*numberOfPix;
 
   QPixmap pix(totalWidth,h);
 
-  pix.fill();  // Fill with white
+  pix.fill(Qt::transparent);
 
   QPainter p(&pix);
 
@@ -366,7 +366,7 @@ void KcmSambaConf::initAdvancedTab()
       icon = il->loadIcon("network-server-database",KIconLoader::Small);
     else {
       icon = QPixmap(16,16);
-      icon.fill();
+      icon.fill(Qt::transparent);
     }
       //SmallIcon("empty2");
 
@@ -708,7 +708,7 @@ void KcmSambaConf::loadSecurity(SambaShare*)
   _dictMngr->add("server schannel",_interface->serverSchannelCombo,
                  new QStringList(QStringList() << "Yes" << "No" << "Auto" ));
   _dictMngr->add("server signing",_interface->serverSigningCombo,
-                 new QStringList(QStringList() << "Auto" << "Mandatory" << "Disabled" ));
+                 new QStringList(QStringList() << "Auto" << "Mandatory" << "No" ));
 
   _dictMngr->add("client lanman auth",_interface->clientLanmanAuthChk);
   _dictMngr->add("client plaintext auth",_interface->clientPlaintextAuthChk);
@@ -717,7 +717,7 @@ void KcmSambaConf::loadSecurity(SambaShare*)
   _dictMngr->add("client schannel",_interface->clientSchannelCombo,
                  new QStringList(QStringList() << "Yes" << "No" << "Auto" ));
   _dictMngr->add("client signing",_interface->clientSigningCombo,
-                 new QStringList(QStringList() << "Auto" << "Mandatory" << "Disabled" ));
+                 new QStringList(QStringList() << "Auto" << "Mandatory" << "No" ));
 
 
 
@@ -863,13 +863,13 @@ void KcmSambaConf::loadProtocol(SambaShare*)
                  new QStringList(QStringList() << "NT" << "NT workstation" << "win95" << "WfW"));
 
   _dictMngr->add("protocol", _interface->protocolCombo,
-                 new QStringList(QStringList() << "NT" << "lanman2" << "lanman1" << "core" << "coreplus" ));
+                 new QStringList(QStringList() << "NT1" << "lanman2" << "lanman1" << "core" << "coreplus" ));
 
   _dictMngr->add("max protocol", _interface->maxProtocolCombo,
-                 new QStringList(QStringList() << "NT" << "lanman2" << "lanman1" << "core" << "coreplus"));
+                 new QStringList(QStringList() << "NT1" << "lanman2" << "lanman1" << "core" << "coreplus"));
 
   _dictMngr->add("min protocol", _interface->minProtocolCombo,
-                 new QStringList(QStringList() << "NT" << "lanman2" << "lanman1" << "core" << "coreplus"));
+                 new QStringList(QStringList() << "NT1" << "lanman2" << "lanman1" << "core" << "coreplus"));
 
 }
 
@@ -985,7 +985,7 @@ void KcmSambaConf::loadWinbind(SambaShare* )
 
   _dictMngr->add("winbind cache time", _interface->winbindCacheTimeSpin);
   _dictMngr->add("acl compatibility",_interface->aclCompatibilityCombo,
-                 new QStringList(QStringList() << "winnt" << "win2k" << ""));
+                 new QStringList(QStringList() << "auto" << "winnt" << "win2k" << ""));
 
   _dictMngr->add("winbind enum users",_interface->winbindEnumUsersChk);
   _dictMngr->add("winbind enum groups",_interface->winbindEnumGroupsChk);
@@ -1240,7 +1240,7 @@ void KcmSambaConf::addSambaUserBtnClicked()
     int passResult = K3PasswordDialog::getNewPassword(this,password,
                         i18n("<qt>Please enter a password for the user <b>%1</b></qt>", user.name));
     if (passResult != K3PasswordDialog::Accepted) {
-       list.remove(item);
+       list.removeAll(item);
        continue;
     }
 
@@ -1259,7 +1259,7 @@ void KcmSambaConf::addSambaUserBtnClicked()
       sambaItem->setDisabled(COL_NOPASSWORD, true);
 
 
-    list.remove(item);
+    list.removeAll(item);
     delete item;
   }
 }
@@ -1280,7 +1280,7 @@ void KcmSambaConf::removeSambaUserBtnClicked()
     }
 
     new K3ListViewItem(_interface->unixUsersListView, item->text(0), item->text(1));
-    list.remove(item);
+    list.removeAll(item);
     delete item;
   }
 }
