@@ -70,7 +70,7 @@ public:
         for (int i = 0; i < args->count(); i++)
         {
             QString txt(args->arg(i));
-            if ( txt.endsWith( ".kgt", Qt::CaseInsensitive ) )
+            if ( txt.endsWith( QLatin1String(".kgt"), Qt::CaseInsensitive ) )
                 KGet::load( txt );
             else
                 l.push_back(KUrl(args->arg(i)));
@@ -80,12 +80,32 @@ public:
         if (splash)
             splash->removeSplash();
 
-        // the last arg read (when we have more than 1 arg) is considered
-        // as destination dir for the previous downloads
-        // if there is a valid local file
+        // if there are exactly two parameters, these may either be
+        // - two valid urls to download, or
+        // - one url and the simple filename to use for saving
+	// - one remote and one local url, the latter being the already user-specified target
+        if (l.count() == 2) {
+            KUrl lastUrl = l.last();
+            if (lastUrl.isLocalFile()) { // either absolute or relative
+                QString targetPath = lastUrl.path();
+		if (targetPath.startsWith('/')) {
+                    KGet::addTransfer(l.first(), lastUrl.path(), QString());
+                 } else {
+		QString fileName = lastUrl.fileName(KUrl::ObeyTrailingSlash);
+                    KGet::addTransfer(l.first(), QString(), fileName);
+                }
+		return 0;
+	    } else if (!lastUrl.isValid() || (lastUrl.scheme().isEmpty() && lastUrl.directory().isEmpty())) {
+	        // Sometimes valid filenames are not recognised by KURL::isLocalFile(), they are marked as invalid then
+                QString suggestedFileName = lastUrl.url();
+		KGet::addTransfer(l.first(), QString(), suggestedFileName);
+		return 0;
+            }
+        }
+
         QString destUrl;
         if (l.count() >= 2 && l.last().isLocalFile()) {
-            if (!QFileInfo(l.last().path()).isDir())
+            if (!QFileInfo(l.last().toLocalFile()).isDir())
                 destUrl = l.last().directory(KUrl::AppendTrailingSlash);
             else
                 destUrl = l.last().path(KUrl::AddTrailingSlash);
@@ -96,9 +116,9 @@ public:
         }
         // all the args read from command line are downloads
         if (l.count() == 1)
-            NewTransferDialog::instance(kget)->showDialog(l.takeFirst().url());
+            KGet::addTransfer(l.takeFirst());
         if (l.count() > 1 && !l.last().isLocalFile())
-            NewTransferDialog::instance(kget)->showDialog(l);
+            KGet::addTransfer(l);
         return 0;
     }
 
@@ -114,7 +134,7 @@ int main(int argc, char *argv[])
                          QByteArray("2." + QByteArray::number(KDE_VERSION_MINOR) + '.' + QByteArray::number(KDE_VERSION_RELEASE)),
                          ki18n("An advanced download manager for KDE"),
                          KAboutData::License_GPL,
-                         ki18n("(C) 2005 - 2008, The KGet developers\n"
+                         ki18n("(C) 2005 - 2009, The KGet developers\n"
                          "(C) 2001 - 2002, Patrick Charbonnier\n"
                          "(C) 2002, Carsten Pfeiffer\n"
                          "(C) 1998 - 2000, Matej Koss"),
@@ -129,7 +149,7 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(ki18n("Carsten Pfeiffer"), ki18n("Former Developer"), "pfeiffer@kde.org");
     aboutData.addAuthor(ki18n("Matej Koss"), ki18n("Former Developer"));
     aboutData.addCredit(ki18n("Joris Guisson"), ki18n("BTCore (KTorrent) Developer"), "joris.guisson@gmail.com");
-    aboutData.addCredit(ki18n("Mensur Zahirovic (Nookie)"), ki18n("Design of Webinterface"), "linuxsajten@gmail.com");
+    aboutData.addCredit(ki18n("Mensur Zahirovic (Nookie)"), ki18n("Design of Web Interface"), "linuxsajten@gmail.com");
 
     KCmdLineArgs::init(argc, argv, &aboutData);
 
