@@ -36,7 +36,7 @@ Transfer * BTTransferFactory::createTransfer(const KUrl &srcUrl, const KUrl &des
 {
     kDebug(5001) << "BTTransferFactory::createTransfer";
 
-    if (srcUrl.fileName().endsWith(".torrent"))
+    if (srcUrl.fileName().endsWith(QLatin1String(".torrent")))
     {
         return new BTTransfer(parent, this, scheduler, srcUrl, destUrl, e);
     }
@@ -91,8 +91,8 @@ const QList<KAction *> BTTransferFactory::actions(TransferHandler *handler)
 
 TransferDataSource * BTTransferFactory::createTransferDataSource(const KUrl &srcUrl)
 {
-    if (srcUrl.fileName().endsWith(".torrent"))
-        return new BTDataSource();
+    /*if (srcUrl.fileName().endsWith(".torrent"))
+        return new BTDataSource();*/
     return 0;
 }
 
