@@ -19,6 +19,8 @@
  ***************************************************************************/
 #include "udptracker.h"
 #include <stdlib.h>
+#include <arpa/inet.h>
+#include <klocale.h>
 #include <util/functions.h>
 #include <util/log.h>
 #include <k3socketaddress.h>
@@ -39,7 +41,7 @@ namespace bt
 	
 
 	UDPTracker::UDPTracker(const KUrl & url,TorrentInterface* tor,const PeerID & id,int tier) 
-	: Tracker(url,tor,id,tier),num_resolve_failures(0)
+	: Tracker(url,tor,id,tier)
 	{
 		num_instances++;
 		if (!socket)
@@ -57,9 +59,8 @@ namespace bt
 				this,SLOT(connectReceived(Int32, Int64 )));
 		connect(socket,SIGNAL(error(Int32, const QString& )),
 				this,SLOT(onError(Int32, const QString& )));
-	
-		KResolver::resolveAsync(this,SLOT(onResolverResults(KNetwork::KResolverResults )),
- 						   url.host(),QString::number(url.port(80)));
+		
+		resolved = false;
 	}
 
 
@@ -179,7 +180,12 @@ namespace bt
 	bool UDPTracker::doRequest()
 	{
 		Out(SYS_TRK|LOG_NOTICE) << "Doing tracker request to url : " << url << endl;
-		if (connection_id == 0)
+		if (!resolved)
+		{
+			KResolver::resolveAsync(this,SLOT(onResolverResults(KNetwork::KResolverResults )),
+									url.host(),QString::number(url.port(80)));
+		}
+		else if (connection_id == 0)
 		{
 			n = 0;
 			sendConnect();
@@ -251,7 +257,7 @@ namespace bt
 		else
 		{
 			KNetwork::KIpAddress addr(cip);
-			WriteUint32(buf,84,addr.IPv4Addr(true));
+			WriteUint32(buf,84,ntohl(addr.IPv4Addr(true)));
 		}
 		WriteUint32(buf,88,key);
 		if (ev != STOPPED)
@@ -283,12 +289,22 @@ namespace bt
 	void UDPTracker::onResolverResults(KResolverResults res)
 	{
 		if (res.count() > 0)
-			address = res.front().address();
-		else if (num_resolve_failures < 3)
 		{
-			num_resolve_failures++;
-			KResolver::resolveAsync(this,SLOT(onResolverResults(KNetwork::KResolverResults )),
-									url.host(),QString::number(url.port(80)));
+			address = res.front().address();
+			resolved = true;
+			// continue doing request
+			if (connection_id == 0)
+			{
+				n = 0;
+				sendConnect();
+			}
+			else
+				sendAnnounce();
+		}
+		else 
+		{
+			n++;
+			requestFailed(i18n("Unable to resolve hostname %1",url.host()));
 		}
 	}
 	
