@@ -46,7 +46,7 @@ protected:
 
 private:
 	class Private;
-	Private *d;
+	Private * const d;
 
 };
 
