@@ -24,12 +24,14 @@
 #include "kopetecontactlistelement.h"
 
 #include <QtCore/QList>
+#include <QtCore/QUuid>
 
 #include <kdemacros.h>
 #include <kurl.h>
 #include "kopete_export.h"
 
 #include "kopeteonlinestatus.h"
+#include "kopetestatusmessage.h"
 
 namespace Kopete {
 
@@ -61,7 +63,7 @@ class KOPETE_EXPORT MetaContact : public ContactListElement
 	Q_PROPERTY( bool isTemporary READ isTemporary )
 	Q_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
 	//Q_PROPERTY( ulong idleTime READ idleTime )
-	Q_PROPERTY( QString metaContactId READ metaContactId WRITE setMetaContactId )
+	Q_PROPERTY( QUuid metaContactId READ metaContactId WRITE setMetaContactId )
 	Q_PROPERTY( bool photoSyncedWithKABC READ isPhotoSyncedWithKABC WRITE setPhotoSyncedWithKABC )
 
 public:
@@ -88,16 +90,28 @@ public:
 	/**
 	 * @brief Returns this metacontact's ID.
 	 *
-	 * Every metacontact has a unique id, set by  when creating the contact, or reading the contact list
-	 * TODO: make it real
+	 * Every metacontact has a unique id, set when creating the contact, 
+	 * or reading the contactlist
 	 */
-	QString metaContactId() const;
+	QUuid metaContactId() const;
+  
+	/**
+	 * @internal
+	 * Set the meta contact id for this meta contact to use. It should only
+	 * be used by the contact list loading mechanism
+	 */
+	void setMetaContactId( const QUuid& newMetaContactId );
 
 	/**
-	 * @brief Add or change the link to a KDE addressbook (KABC) Addressee.
-	 * FIXME: Use with care.  You could create 1 to many relationships with the current implementation
+	 * @brief Get the KABC id for this metacontact
 	 */
-	void setMetaContactId( const QString& newMetaContactId );
+	QString kabcId() const;
+
+	/**
+	 * @brief Set the KABC id for this metacontact
+	 * Use with care! You could create a one to many relationship
+	 */
+	void setKabcId( const QString& newKabcId );
 
 	/**
 	 * @brief Retrieve the list of contacts that are part of the meta contact
@@ -348,7 +362,7 @@ public:
 	/**
 	 * return the time in second the contact is idle.
 	 */
-	unsigned long int idleTime() const;
+	quint32 idleTime() const;
 
 	/**
 	 * Get or set a field for the KDE address book backend. Fields not
@@ -382,6 +396,11 @@ public:
 	 */
 	void setAddressBookField( Plugin *p, const QString &app, const QString &key, const QString &value );
 
+	/**
+	 * @brief The status message of metacontact
+	 */
+	StatusMessage statusMessage() const;
+
 public slots:
 
 	/**
@@ -402,23 +421,22 @@ public slots:
 		unsigned long fileSize = 0L );
 
 	/**
-	 * Emit aboutToSave signal to notify plugins that this metaContact is going to be saved
+	 * Serialize this metaContact
+	 * This causes each Kopete::Protocol subclass to serialise its contacts' data into the metacontact's plugin data
 	 */
-	void emitAboutToSave();
+	void serialize();
 
 signals:
-	/**
-	 * This metaContact is going to be saved to the contact list. Plugins should
-	 * connect to this signal to update data with setPluginData()
-	 */
-	void aboutToSave( Kopete::MetaContact *metaContact );
-
 	/**
 	 * One of the subcontacts' idle status has changed.  As with online status,
 	 * this can occur without the metacontact changing idle state
 	 */
 	void contactIdleStateChanged( Kopete::Contact *contact );
 
+	/**
+	 * Status title or message has changed
+	 */
+	void statusMessageChanged( Kopete::MetaContact *metaContact );
 
 public slots:
 
@@ -489,6 +507,11 @@ public slots:
 	 */
 	void slotPluginLoaded( Kopete::Plugin *plugin );
 
+	/**
+	 * If a protocol is loaded, deserialize cached data
+	 */
+	void slotProtocolLoaded( Kopete::Protocol *p );
+
 signals:
 	/**
 	 *  @brief The MetaContact online status changed
@@ -583,6 +606,8 @@ protected:
 	//QString nameFromContact( Kopete::Contact *c) const;
 	//QString nameFromKABC( const QString &id ) const;
 
+	void onlineStatusNotification( Kopete::Contact * c );
+
 private:
 	class Private;
 	Private * const d;
