@@ -1,56 +1,57 @@
-/***************************************************************************
-                          texteffectpreferences.cpp  -  description
-                             -------------------
-    begin                : jeu nov 14 2002
-    copyright            : (C) 2002 by Olivier Goffart
-    email                : ogoffart @ kde.org
- ***************************************************************************/
+/*
+    texteffectpreferences.cpp  -  description
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    Copyright (c) 2002      by Olivier Goffart <ogoffart@kde.org>
+
+    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+
+    ***************************************************************************
+    *                                                                         *
+    *   This program is free software; you can redistribute it and/or modify  *
+    *   it under the terms of the GNU General Public License as published by  *
+    *   the Free Software Foundation; either version 2 of the License, or     *
+    *   (at your option) any later version.                                   *
+    *                                                                         *
+    ***************************************************************************
+*/
 
 #include <qstring.h>
 #include <qlayout.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
 
 #include <klocale.h>
 #include <kcolordialog.h>
 #include <kgenericfactory.h>
-#include <kautoconfig.h>
 #include <kdebug.h>
 
 #include <kdeversion.h>
 
-#include "texteffectprefs.h"
+#include "ui_texteffectprefs.h"
 #include "texteffectpreferences.h"
 #include "texteffectconfig.h"
 
-typedef KGenericFactory<TextEffectPreferences> TextEffectPreferencesFactory;
-K_EXPORT_COMPONENT_FACTORY( kcm_kopete_texteffect, TextEffectPreferencesFactory( "kcm_kopete_texteffect" )  )
+K_PLUGIN_FACTORY(TextEffectPreferencesFactory, registerPlugin<TextEffectPreferences>();)
+K_EXPORT_PLUGIN(TextEffectPreferencesFactory( "kcm_kopete_texteffect" ))
 
 TextEffectPreferences::TextEffectPreferences(QWidget *parent,
-                                             const char* /*name*/,
-                                             const QStringList &args)
-	: KCModule(TextEffectPreferencesFactory::instance(), parent, args)
+                                             const QVariantList &args)
+	: KCModule(TextEffectPreferencesFactory::componentData(), parent, args)
 {
-	( new QVBoxLayout( this ) )->setAutoAdd( true );
+	QVBoxLayout* l = new QVBoxLayout( this );
+	QWidget *w = new QWidget;
+	kDebug( 14310 ) << "Creating preferences dialog";
+	preferencesDialog = new Ui::TextEffectPrefs;
+	preferencesDialog->setupUi( w );
+	l->addWidget( w );
 
-	kdDebug( 14310 ) << "Creating preferences dialog" << endl;
-
-	preferencesDialog = new TextEffectPrefs(this);
-
-	kdDebug( 14310 ) << "Creating config object" << endl;
+	kDebug( 14310 ) << "Creating config object";
 
 	config = new TextEffectConfig;
 
-	kdDebug( 14310 ) << "Setting up connections" << endl;
+	kDebug( 14310 ) << "Setting up connections";
 
 	connect(preferencesDialog->mColorsAdd , SIGNAL(pressed()) ,
 			this , SLOT(slotAddPressed()));
@@ -80,9 +81,6 @@ TextEffectPreferences::TextEffectPreferences(QWidget *parent,
 			 this, SLOT( slotSettingChanged() ) );
 
 	//setMainWidget( preferencesDialog, "Text Effect Plugin" );
-
-	load();
-
 }
 
 TextEffectPreferences::~TextEffectPreferences()
@@ -94,7 +92,7 @@ TextEffectPreferences::~TextEffectPreferences()
 
 void TextEffectPreferences::load()
 {
-	kdDebug( 14310 ) << k_funcinfo << "ENTER" << endl;
+	kDebug( 14310 ) << "ENTER";
 
 	config->load();
 
@@ -112,13 +110,13 @@ void TextEffectPreferences::load()
 	// Indicate that we have not changed ^_^
 	emit changed( false );
 
-	kdDebug( 14310 ) << k_funcinfo << "EXIT" << endl;
+	kDebug( 14310 ) << "EXIT";
 
 }
 
 void TextEffectPreferences::save()
 {
-	kdDebug() << k_funcinfo << "ENTER" << endl;
+	kDebug() << "ENTER";
 	// Save the settings
 	config->setColors(colors());
 	config->setColorRandom(preferencesDialog->m_colorRandom->isChecked());
@@ -139,7 +137,7 @@ void TextEffectPreferences::save()
 
 	// Indicate that we have not changed ^_^
 	emit changed( false );
-	kdDebug() << k_funcinfo << "EXIT" << endl;
+	kDebug() << "EXIT";
 }
 
 QStringList TextEffectPreferences::colors()
@@ -177,7 +175,7 @@ void TextEffectPreferences::slotUpPressed()
 	int p=preferencesDialog->mColorsListBox->currentItem();
 	if(p <= 0 )
 		return;
-	QListBoxItem *i=preferencesDialog->mColorsListBox->selectedItem();
+	Q3ListBoxItem *i=preferencesDialog->mColorsListBox->selectedItem();
 	if(!i)
 		return;
 	preferencesDialog->mColorsListBox->setSelected(i,false);
@@ -194,7 +192,7 @@ void TextEffectPreferences::slotDownPressed()
 	int p=preferencesDialog->mColorsListBox->currentItem();
 	if(p < 0 )
 		return;
-	QListBoxItem *i=preferencesDialog->mColorsListBox->selectedItem();
+	Q3ListBoxItem *i=preferencesDialog->mColorsListBox->selectedItem();
 	if(!i)
 		return;
 	preferencesDialog->mColorsListBox->setSelected(i,false);
@@ -210,7 +208,7 @@ void TextEffectPreferences::slotDownPressed()
 
 void TextEffectPreferences::slotSettingChanged()
 {
-	kdDebug() << k_funcinfo << "Called"
+	kDebug() << "Called"
 			  << endl;
 	// Indicate that our settings have changed
     emit changed( true );
