@@ -2,6 +2,7 @@
     Kopete Groupwise Protocol
     gwchatsearchdialog.cpp - dialog for searching for chatrooms
 
+    Copyright (c) 2006      Novell, Inc	 	 	 http://www.opensuse.org
     Copyright (c) 2005      SUSE Linux AG	 	 http://www.suse.com
     
     Kopete (c) 2002-2005 by the Kopete developers <kopete-devel@kde.org>
@@ -18,8 +19,8 @@
 
 #include <qmap.h>
 
-#include <klistview.h>
-#include <klistviewsearchline.h>
+#include <k3listview.h>
+#include <k3listviewsearchline.h>
 
 #include <kpushbutton.h>
 #include <kdebug.h>
@@ -29,18 +30,22 @@
 
 #include "gwaccount.h"
 #include "gwprotocol.h"
-#include "gwchatsearchwidget.h"
 #include "gwchatpropsdialog.h"
 
 #include "gwchatsearchdialog.h"
 
 GroupWiseChatSearchDialog::GroupWiseChatSearchDialog( GroupWiseAccount * account, QWidget *parent, const char *name )
-	: KDialogBase(  parent, name, false, i18n( "Search Chatrooms" ),
-					KDialogBase::Ok|KDialogBase::Apply|KDialogBase::Cancel, Ok, true ), m_account( account )
+	: KDialog(  parent),
+					m_account( account )
 {
-	m_widget = new GroupWiseChatSearchWidget( this );
-//	m_widget->m_searchLineWidget->createSearchLine( m_widget->m_chatrooms );
-	setMainWidget( m_widget );
+	QWidget * wid = new QWidget( this );
+	m_ui.setupUi( wid );
+	setMainWidget( wid );
+	setCaption(i18n( "Search Chatrooms" ));
+	setButtons(KDialog::Ok|KDialog::Apply|KDialog::Cancel);
+	setDefaultButton(Ok);
+	showButtonSeparator(true);
+//	m_ui.searchLineWidget->createSearchLine( m_ui.chatrooms );
 
 	m_manager = m_account->client()->chatroomManager();
 	
@@ -48,8 +53,8 @@ GroupWiseChatSearchDialog::GroupWiseChatSearchDialog( GroupWiseAccount * account
 	connect ( m_manager, SIGNAL( gotProperties( const GroupWise::Chatroom & ) ),
 			  SLOT( slotGotProperties( const GroupWise::Chatroom & ) ) );
 
-	connect( m_widget->m_btnRefresh, SIGNAL( clicked() ), SLOT( slotUpdateClicked() ) );
-	connect( m_widget->m_btnProperties, SIGNAL( clicked() ), SLOT( slotPropertiesClicked() ) );
+	connect( m_ui.btnRefresh, SIGNAL( clicked() ), SLOT( slotUpdateClicked() ) );
+	connect( m_ui.btnProperties, SIGNAL( clicked() ), SLOT( slotPropertiesClicked() ) );
 
 	m_manager->updateRooms();
 	show();
@@ -61,36 +66,36 @@ GroupWiseChatSearchDialog::~GroupWiseChatSearchDialog()
 
 void GroupWiseChatSearchDialog::slotUpdateClicked()
 {
-	kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << "updating chatroom list " << endl;
-	m_widget->m_chatrooms->clear();
-	QListViewItem * first = m_widget->m_chatrooms->firstChild();
+	kDebug () << "updating chatroom list ";
+	Q3ListViewItem * first = m_ui.chatrooms->firstChild();
 	QString updateMessage = i18n("Updating chatroom list..." );
-/*	if ( first )
-		new QListViewItem( first, updateMessage );
-	else*/
-		new QListViewItem( m_widget->m_chatrooms, updateMessage );
+	if ( first )
+		new Q3ListViewItem( first, updateMessage );
+	else
+		new Q3ListViewItem( m_ui.chatrooms, updateMessage );
 	m_manager->updateRooms();
 
 }
 
 void GroupWiseChatSearchDialog::slotManagerUpdated()
 {
+	m_ui.chatrooms->clear();
 	ChatroomMap rooms = m_manager->rooms();
 	ChatroomMap::iterator it = rooms.begin();
 	const ChatroomMap::iterator end = rooms.end();
 	while ( it != end )
 	{
-		new QListViewItem( m_widget->m_chatrooms,
-						   it.data().displayName,
-						   m_account->protocol()->dnToDotted( it.data().ownerDN ),
-						   QString::number( it.data().participantsCount ) );
+		new Q3ListViewItem( m_ui.chatrooms,
+						   it.value().displayName,
+						   m_account->protocol()->dnToDotted( it.value().ownerDN ),
+						   QString::number( it.value().participantsCount ) );
 		++it;
 	}
 }
 
 void GroupWiseChatSearchDialog::slotPropertiesClicked()
 {
-	QListViewItem * selected  = m_widget->m_chatrooms->selectedItem();
+	Q3ListViewItem * selected  = m_ui.chatrooms->selectedItem();
 	if ( selected )
 	{
 		m_manager->requestProperties( selected->text( 0 ) );
@@ -99,8 +104,8 @@ void GroupWiseChatSearchDialog::slotPropertiesClicked()
 
 void GroupWiseChatSearchDialog::slotGotProperties(const GroupWise::Chatroom & room)
 {
-	kdDebug( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << endl;
-	new GroupWiseChatPropsDialog( room, true, this, "chatpropsdlg" );
+	kDebug() ;
+	new GroupWiseChatPropsDialog( room, true, this );
 }
 
 #include "gwchatsearchdialog.moc"
