@@ -280,7 +280,7 @@ void IRCNetworkConfigWidget::slotDeleteNetwork()
 	QString network = m_networkList->currentText();
 	if( KMessageBox::warningContinueCancel(
 		UI::Global::mainWidget(), i18n("<qt>Are you sure you want to delete the network <b>%1</b>?<br>"
-		"Any account which use this network will have to be modified.</qt>")
+		"Any accounts which use this network will have to be modified.</qt>")
 		.arg(network), i18n("Deleting Network"),
 		KGuiItem(i18n("&Delete Network"),"edit-delete"), KStandardGuiItem::cancel(), QString::fromLatin1("AskIRCDeleteNetwork") ) == KMessageBox::Continue )
 	{
