@@ -4,8 +4,9 @@
 
     Copyright 2006 Chani Armitage <chanika@gmail.com>
     Copyright 2007 Matt Rogers <mattr@kde.org>
+    Copyright 2008 Roman Jarosz <kedgedev@centrum.cz>
 
-    Kopete ( c ) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
+    Kopete ( c ) 2002-2008 by the Kopete developers <kopete-devel@kde.org>
 
     based on ssidata.h and ssidata.cpp ( c ) 2002 Tom Linsky <twl6@po.cwru.edu>
 
@@ -26,9 +27,11 @@
 #include <QtNetwork/QHostAddress>
 #include <QtNetwork/QTcpServer>
 #include <QtNetwork/QTcpSocket>
+#include <QtXml/QDomDocument>
 
 #include <ksocketfactory.h>
 #include <krandom.h>
+#include <kio/global.h>
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -40,8 +43,6 @@
 #include "oscarsettings.h"
 #include "oftmetatransfer.h"
 
-#include "kopetetransfermanager.h"
-
 //receive
 FileTransferTask::FileTransferTask( Task* parent, const QString& contact,
                                     const QString& self, QByteArray cookie,
@@ -57,8 +58,7 @@ FileTransferTask::FileTransferTask( Task* parent, const QString& contact,
 
 //send
 FileTransferTask::FileTransferTask( Task* parent, const QString& contact,
-                                    const QString& self, const QStringList& files,
-                                    Kopete::Transfer *transfer )
+                                    const QString& self, const QStringList& files )
 :Task( parent ), m_contactName( contact ),
  m_selfName( self ), m_timer( this )
 {
@@ -85,18 +85,6 @@ FileTransferTask::FileTransferTask( Task* parent, const QString& contact,
 	cookie = KRandom::random();
 	b.addDWord( cookie );
 	m_oftRendezvous.cookie = b.buffer();
-
-	//hook up ui cancel
-	connect( transfer, SIGNAL(result(KJob*)), this, SLOT(transferResult(KJob*)) );
-#ifdef __GNUC__
-#warning Remove connection below when transferResult correctly sends cancel from cancel button. (Kedge)
-#endif
-	connect( transfer, SIGNAL(finished(KJob*)), this, SLOT(doCancel()) );
-	//hook up our ui signals
-	connect( this, SIGNAL(transferCancelled()), transfer, SLOT(slotCancelled()) );
-	connect( this, SIGNAL(transferError(int, const QString&)), transfer, SLOT(slotError(int, const QString&)) );
-	connect( this, SIGNAL(transferProcessed(unsigned int)), transfer, SLOT(slotProcessed(unsigned int)) );
-	connect( this, SIGNAL(transferFinished()), transfer, SLOT(slotComplete()) );
 }
 
 void FileTransferTask::init( Action act )
@@ -108,6 +96,7 @@ void FileTransferTask::init( Action act )
 	m_proxy = false;
 	m_proxyRequester = false;
 	m_state = Default;
+	m_fileFinishedBytes = 0;
 }
 
 FileTransferTask::~FileTransferTask()
@@ -127,20 +116,41 @@ FileTransferTask::~FileTransferTask()
 	kDebug(OSCAR_RAW_DEBUG) << "done";
 }
 
+QString FileTransferTask::internalId() const
+{
+	return QString( m_oftRendezvous.cookie.toHex() );
+}
+
+QString FileTransferTask::contactName() const
+{
+	return m_contactName;
+}
+
+QString FileTransferTask::fileName() const
+{
+	return m_oftRendezvous.fileName;
+}
+
+Oscar::WORD FileTransferTask::fileCount() const
+{
+	return m_oftRendezvous.fileCount;
+}
+
+Oscar::DWORD FileTransferTask::totalSize() const
+{
+	return m_oftRendezvous.totalSize;
+}
+
+QString FileTransferTask::description() const
+{
+	return m_desc;
+}
+
 void FileTransferTask::onGo()
 {
 	if ( m_action == Receive )
-	{
-		//we have to send a signal because liboscar isn't supposed to know about OscarContact.
-
-		Kopete::TransferManager *tm = 0;
-		emit getTransferManager( &tm );
-		connect( tm, SIGNAL(refused(const Kopete::FileTransferInfo&)), this, SLOT(doCancel(const Kopete::FileTransferInfo&)) );
-		connect( tm, SIGNAL(accepted(Kopete::Transfer*, const QString&)), this, SLOT(doAccept(Kopete::Transfer*, const QString&)) );
-
-		emit askIncoming( m_contactName, m_oftRendezvous.fileName, m_oftRendezvous.totalSize, m_desc, m_oftRendezvous.cookie.toHex() );
 		return;
-	}
+
 	//else, send
 	if ( m_contactName.isEmpty() )
 	{
@@ -217,7 +227,7 @@ void FileTransferTask::parseReq( Buffer b )
 			kDebug(OSCAR_RAW_DEBUG) << "port " << m_port;
 			break;
 		 case 0x0c:
-			m_desc = tlv.data; //FIXME: what codec?
+			m_desc = parseDescription( tlv.data ); //FIXME: what codec?
 			kDebug(OSCAR_RAW_DEBUG) << "user message: " << tlv.data;
 			break;
 		 case 0x0d:
@@ -444,14 +454,21 @@ void FileTransferTask::doOft()
 	OftMetaTransfer *oft;
 
 	if ( m_action == Receive )
-		oft = new OftMetaTransfer( m_oftRendezvous.cookie, m_oftRendezvous.dir, m_connection );
+		oft = new OftMetaTransfer( m_oftRendezvous.cookie, m_oftRendezvous.files, m_oftRendezvous.dir, m_connection );
 	else
 		oft = new OftMetaTransfer( m_oftRendezvous.cookie, m_oftRendezvous.files, m_connection );
 
 	m_connection = 0; //it's not ours any more
 	//might be a good idea to hook up some signals&slots.
+	connect( oft, SIGNAL(fileStarted(const QString&, unsigned int)),
+	         this, SIGNAL(nextFile(const QString&, unsigned int)) );
+	connect( oft, SIGNAL(fileStarted(const QString&, const QString&)),
+	         this, SIGNAL(nextFile(const QString&, const QString&)) );
 	connect( oft, SIGNAL(fileProcessed(unsigned int, unsigned int)),
-	         this, SIGNAL(transferProcessed(unsigned int)) );
+	         this, SLOT(fileProcessedOft(unsigned int, unsigned int)) );
+	connect( oft, SIGNAL(fileFinished(const QString&, unsigned int)),
+	         this, SLOT(fileFinishedOft(const QString&, unsigned int)) );
+
 	connect( oft, SIGNAL(transferError(int, const QString&)),
 	         this, SLOT(errorOft(int, const QString&)) );
 	connect( oft, SIGNAL(transferCompleted()), this, SLOT(doneOft()) );
@@ -461,7 +478,19 @@ void FileTransferTask::doOft()
 		oft->start();
 }
 
-void FileTransferTask::errorOft( int errorCode, const QString &error )
+void FileTransferTask::fileProcessedOft( unsigned int bytesSent, unsigned int fileSize )
+{
+	unsigned int bytesSentTotal = m_fileFinishedBytes + bytesSent;
+	emit fileProcessed( bytesSent, fileSize );
+	emit transferProcessed( bytesSentTotal );
+}
+
+void FileTransferTask::fileFinishedOft( const QString& /*fileName*/, unsigned int fileSize )
+{
+	m_fileFinishedBytes += fileSize;
+}
+
+void FileTransferTask::errorOft( int /*errorCode*/, const QString &error )
 {
 	emit transferError( KIO::ERR_USER_CANCELED, error );
 	doCancel();
@@ -473,12 +502,6 @@ void FileTransferTask::doneOft()
 	setSuccess( true );
 }
 
-void FileTransferTask::transferResult( KJob* job )
-{
-	if( job->error() == KIO::ERR_USER_CANCELED )
-		doCancel();
-}
-
 void FileTransferTask::socketError( QAbstractSocket::SocketError e )
 { //FIXME: handle this properly for all cases
 	QString desc;
@@ -583,53 +606,52 @@ void FileTransferTask::doCancel()
 }
 
 
-void FileTransferTask::doCancel( const Kopete::FileTransferInfo &info )
+void FileTransferTask::doAccept( const QString &localDirecotry )
 {
-	kDebug(OSCAR_RAW_DEBUG) ;
-	//check that it's really for us
-	if ( info.internalId() == QString( m_oftRendezvous.cookie.toHex() ) )
-		doCancel();
-	else
-		kDebug(OSCAR_RAW_DEBUG) << "ID mismatch";
-}
+	kDebug(OSCAR_RAW_DEBUG) << "directory: " << localDirecotry;
+	m_oftRendezvous.files.clear();
+	m_oftRendezvous.dir = localDirecotry + '/';
 
-void FileTransferTask::doAccept( Kopete::Transfer *t, const QString & localName )
-{
-	kDebug(OSCAR_RAW_DEBUG) ;
-	//check that it's really for us
-	if ( t->info().internalId() != QString( m_oftRendezvous.cookie.toHex() ) )
-	{
-		kDebug(OSCAR_RAW_DEBUG) << "ID mismatch";
-		return;
-	}
-
-	//TODO: we should unhook the old transfermanager signals now
-	//hook up the ones for the transfer
-	connect( t, SIGNAL(result(KJob*)), this, SLOT(transferResult(KJob*)) );
-#ifdef __GNUC__
-#warning Remove connection below when transferResult correctly sends cancel from cancel button. (Kedge)
-#endif
-	connect( t, SIGNAL(finished(KJob*)), this, SLOT(doCancel()) );
-	connect( this, SIGNAL(transferCancelled()), t, SLOT(slotCancelled()) );
-	connect( this, SIGNAL(transferError(int, const QString&)), t, SLOT(slotError(int, const QString&)) );
-	connect( this, SIGNAL(transferProcessed(unsigned int)), t, SLOT(slotProcessed(unsigned int)) );
-	connect( this, SIGNAL(transferFinished()), t, SLOT(slotComplete()) );
-	//and save the chosen filename
-
-	/*FIXME: Should we prompt for a file name if we receive one file or only for a directory like the official
-	         icq and aim clients (if we have multiple files we don't know their names at this stage) */
-#ifdef __GNUC__
-#warning Hack, this will be removed as soon as I add a function into Kopete::TransferManager that will prompt for a directory (Kedge)
-#endif
-	QFileInfo fileInfo( localName );
-	m_oftRendezvous.dir = fileInfo.absolutePath() + '/';
-
-	if( validDir( m_oftRendezvous.dir ) )
+	if ( validDir( m_oftRendezvous.dir ) )
 		doConnect();
 	else
 		doCancel();
 }
 
+void FileTransferTask::doAccept( const QStringList &localFileNames )
+{
+	kDebug(OSCAR_RAW_DEBUG) << "file names: " << localFileNames;
+	if ( localFileNames.isEmpty() )
+	{
+		doCancel();
+		return;
+	}
+
+	m_oftRendezvous.files = localFileNames;
+
+	// Set default path from first file name in case we get more
+	// files then we have in localFileNames.
+	QFileInfo fileInfo( m_oftRendezvous.files.first() );
+	m_oftRendezvous.dir = fileInfo.absolutePath() + '/';
+
+	for ( int i = 0; i < m_oftRendezvous.files.count(); ++i )
+	{
+		if ( !validFile( m_oftRendezvous.files.at(i) ) )
+		{
+			doCancel();
+			return;
+		}
+	}
+
+	if ( m_oftRendezvous.files.count() < m_oftRendezvous.fileCount && !validDir( m_oftRendezvous.dir ) )
+	{
+		doCancel();
+		return;
+	}
+
+	doConnect();
+}
+
 void FileTransferTask::doConnect()
 {
 	kDebug(OSCAR_RAW_DEBUG) ;
@@ -853,6 +875,29 @@ Oscar::Message FileTransferTask::makeFTMsg()
 	return msg;
 }
 
+QString FileTransferTask::parseDescription( const QByteArray &description ) const
+{
+	QString xmlDesc = QString::fromUtf8( description );
+	xmlDesc.replace( QLatin1String( "&gt;" ), QLatin1String( ">" ) );
+	xmlDesc.replace( QLatin1String( "&lt;" ), QLatin1String( "<" ) );
+	xmlDesc.replace( QLatin1String( "&quot;" ), QLatin1String( "\"" ) );
+	xmlDesc.replace( QLatin1String( "&nbsp;" ), QLatin1String( " " ) );
+	xmlDesc.replace( QLatin1String( "&amp;" ), QLatin1String( "&" ) );
+	
+	QDomDocument xmlDocument;
+	if ( !xmlDocument.setContent( xmlDesc ) )
+	{
+		kDebug(OSCAR_RAW_DEBUG) << "Cannot parse description!";
+		return QString::fromUtf8( description );
+	}
+	
+	QDomNodeList descList = xmlDocument.elementsByTagName( "DESC" );
+	if ( descList.count() == 1 )
+		return descList.at( 0 ).toElement().text();
+	else
+		return QString::fromUtf8( description );
+}
+
 #include "filetransfertask.moc"
 //kate: space-indent off; tab-width 4; indent-mode csands;
 
