@@ -358,9 +358,11 @@ void SkypeAccount::newUser(const QString &name, int groupID) {
 
 	Kopete::Group * skypeGroup;
 
-	if (group.isEmpty() || groupID == -1) // If skype group hasnt name, in kopete will be in top
+	bool root = false;
+	if (group.isEmpty() || groupID == -1) { // If skype group hasnt name, in kopete will be in top
 		skypeGroup = Kopete::Group::topLevel();
-	else {
+		root = true;
+	} else {
 		skypeGroup = Kopete::ContactList::self()->findGroup(group); //get kopete group by skype group name. If skype group in kopete doesnt exist, create it automatically
 		if ( skypeGroup == Kopete::Group::topLevel() ){ //if group in skype has name i18n("Top Level") kopete get top level group, but in skype top level group is group without name
 			QList <Kopete::Group *> groups = Kopete::ContactList::self()->groups(); //get all groups
@@ -380,9 +382,14 @@ void SkypeAccount::newUser(const QString &name, int groupID) {
 
 	Kopete::Contact * contact = contacts().value(name);
 	if (contact){
-		if (skypeGroup != contact->metaContact()->groups().first()){ // if skype Group is different like kopete group, move metacontact to skype group
-			kDebug(SKYPE_DEBUG_GLOBAL) << "Moving contact" << name << "to group" << group;
-			contact->metaContact()->moveToGroup(contact->metaContact()->groups().first(), skypeGroup);
+		if (!root) {
+			if (skypeGroup != contact->metaContact()->groups().first()){ //if skype Group is different like kopete group (and skype group isnt root), move metacontact to skype group
+				kDebug(SKYPE_DEBUG_GLOBAL) << "Moving contact" << name << "to group" << group;
+				contact->metaContact()->moveToGroup(contact->metaContact()->groups().first(), skypeGroup);
+			}
+		} else { //if skype contact is in root group, move it to kopete group
+			kDebug(SKYPE_DEBUG_GLOBAL) << "Moving contact" << name << "in skype client to kopete group";
+			MovedBetweenGroup(static_cast <SkypeContact *> (contact));
 		}
 		return;
 	}
@@ -503,7 +510,7 @@ void SkypeAccount::setCallControl(bool value) {
 void SkypeAccount::newCall(const QString &callId, const QString &userId) {
 	kDebug(SKYPE_DEBUG_GLOBAL);
 
-	if (d->callControl) {//Show the skype call control window
+	if (d->callControl) {//Show the kopete call control window
 		SkypeCallDialog *dialog = new SkypeCallDialog(callId, userId, this);//It should free itself when it is closed
 
 		QObject::connect(&d->skype, SIGNAL(callStatus(const QString&, const QString& )), dialog, SLOT(updateStatus(const QString&, const QString& )));
@@ -558,7 +565,7 @@ QString SkypeAccount::getUserLabel(const QString &userId) {
 	Kopete::Contact *cont = contact(userId);
 
 	if (!cont) {
-		addContact(userId, QString::null, 0L, Temporary);//create a temporary contact
+		addContact(userId, d->skype.getDisplayName(userId), 0L, Temporary);//create a temporary contact
 
 		cont = (contacts().value(userId));//It should be there now
 		if (!cont)
@@ -621,7 +628,7 @@ int SkypeAccount::getWaitBeforeConnect() const {
 SkypeContact *SkypeAccount::getContact(const QString &userId) {
 	SkypeContact *cont = static_cast<SkypeContact *> (contacts().value(userId));//get the contact
 	if (!cont) {//We do not know such contact
-		addContact(userId, QString::null, 0L, Temporary);//create a temporary contact
+		addContact(userId, d->skype.getDisplayName(userId), 0L, Temporary);//create a temporary contact
 
 		cont = static_cast<SkypeContact *> (contacts().value(userId));//It should be there now
 	}
@@ -1021,6 +1028,8 @@ void SkypeAccount::SkypeActionHandler(const QString &message) {
 	} else if ( message.startsWith("skype:", Qt::CaseInsensitive) ) {
 		command = message.section("?", -1).trimmed();
 		user = message.section(":", -1).section("?", 0, 0).trimmed();
+		if ( command.isEmpty() ) //set default double click action = open chat window
+			command = "chat";
 	} else
 		return;//Unknow message
 
@@ -1039,7 +1048,7 @@ void SkypeAccount::SkypeActionHandler(const QString &message) {
 		openFileTransfer(user);//Open file transfer dialog
 	} else if ( command == "userinfo" ) {//TODO: Open option dialog (with all thisa options instead userinfo) and support unknow contacts who arent in contact list
 		if ( ! contact(user) ) {
-			addContact(user, QString::null, 0L, Temporary);//create a temporary contact
+			addContact(user, d->skype.getDisplayName(user), 0L, Temporary);//create a temporary contact
 			if ( ! contact(user) )
 				return;//contact arent in contact list - skip it
 		}
