@@ -1,6 +1,6 @@
 /*
  *
- * $Id: pppstats.cpp 767549 2008-01-28 10:19:31Z espie $
+ * $Id: pppstats.cpp 1014225 2009-08-21 23:24:18Z pino $
  *
  * History:
  *
@@ -92,7 +92,7 @@
 
 #endif	/* STREAMS */
 
-#if defined __OpenBSD__
+#if defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
  #include <sys/socket.h>
  #include <net/if.h>
  #include <net/if_ppp.h>
