@@ -1,7 +1,7 @@
 /****************************************************************************
 **
 ** Copyright (C) 2001-2003 Tim Jansen <tim@tjansen.de>
-** Copyright (C) 2007 Urs Wolfer <uwolfer @ kde.org>
+** Copyright (C) 2007 - 2008 Urs Wolfer <uwolfer @ kde.org>
 **
 ** This file is part of KDE.
 **
@@ -30,11 +30,15 @@
 #include <KAboutData>
 #include <KDebug>
 
+#include <QTime>
+
 int main(int argc, char **argv)
 {
+    QTime startupTimer;;
+    startupTimer.start();
     KAboutData aboutData("krdc", 0, ki18n("KRDC"), KDE_VERSION_STRING,
                          ki18n("KDE remote desktop connection"), KAboutData::License_GPL,
-                         ki18n("(c) 2007-2008, Urs Wolfer\n"
+                         ki18n("(c) 2007-2009, Urs Wolfer\n"
                                "(c) 2001-2003, Tim Jansen\n"
                                "(c) 2002-2003, Arend van Beelen jr.\n"
                                "(c) 2000-2002, Const Kaplinsky\n"
@@ -66,7 +70,7 @@ int main(int argc, char **argv)
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     if (args->count() > 0) {
-        for (int i = 0; i < args->count(); i++) {
+        for (int i = 0; i < args->count(); ++i) {
             KUrl u(args->url(i));
 
             if (u.scheme().isEmpty() || u.host().isEmpty()) { // unusable url; try to recover it...
@@ -91,6 +95,8 @@ int main(int argc, char **argv)
             mainwindow->newConnection(u, ((args->isSet("fullscreen")) && (args->count() == 1)));
         }
     }
+    
+    kDebug(5010) << "########## KRDC ready:" << startupTimer.elapsed()<< "ms ##########";
 
     return app.exec();
 }
