@@ -83,13 +83,13 @@ private:
 class ClientCutEvent : public ClientEvent
 {
 public:
-    ClientCutEvent(char *text)
+    ClientCutEvent(const QString &text)
             : text(text) {}
 
     void fire(rfbClient*);
 
 private:
-    char *text;
+    QString text;
 };
 
 class VncClientThread: public QThread
@@ -132,6 +132,9 @@ protected:
     void run();
 
 private:
+    static rfbBool newclient(rfbClient *cl);
+    static void updatefb(rfbClient *cl, int x, int y, int w, int h);
+    static void cuttext(rfbClient *cl, const char *text, int textlen);
     static char* passwdHandler(rfbClient *cl);
     static void outputHandler(const char *format, ...);
 
